package com.uas.search.console.b2b.model;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Table;

/**
 * 买家的采购验退单
 * 
 * @author suntg
 * 
 */
@Table(name = PurchaseReturnSimpleInfo.TABLE_NAME)
@Entity
public class PurchaseReturnSimpleInfo {

	/**
	 * 表名
	 */
	public static final String TABLE_NAME = "PURC$RETURN";

	/**
	 * 各字段列名（也是存储索引时的field名）
	 */
	public static final String ID_FIELD = "pr_id";

	public static final String CODE_FIELD = "pr_code";

	public static final String ENTERPRISE_FIELD = "pr_enuu";

	public static final String DATE_FIELD = "pr_date";

	public static final String SENDCODE_FIELD = "pr_sendcode";

	public static final String VEND_FIELD = "pr_venduu";

	public static final String ITEMS_FIELD = "pri_prid";

	@Id
	@Column(name = ID_FIELD)
	private Long id;

	/**
	 * 单号
	 */
	@Column(name = CODE_FIELD)
	private String code;

	/**
	 * 送货单号
	 */
	@Column(name = SENDCODE_FIELD)
	private String sendCode;

	/**
	 * 日期
	 */
	@Column(name = DATE_FIELD)
	private Date date;

	/**
	 * 企业UU
	 */
	@OneToOne
	@JoinColumn(name = ENTERPRISE_FIELD, insertable = false, updatable = false)
	private EnterpriseSimpleInfo enterprise;

	/**
	 * 供应商
	 */
	@OneToOne
	@JoinColumn(name = VEND_FIELD, insertable = false, updatable = false)
	private EnterpriseSimpleInfo vend;

	/**
	 * 验收明细
	 */
	@OneToMany(cascade = { CascadeType.ALL }, fetch = FetchType.EAGER)
	@JoinColumn(name = ITEMS_FIELD, updatable = false, insertable = false)
	private Set<PurchaseReturnItemSimpleInfo> returnItems;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getSendCode() {
		return sendCode;
	}

	public void setSendCode(String sendCode) {
		this.sendCode = sendCode;
	}

	public EnterpriseSimpleInfo getVend() {
		return vend;
	}

	public void setVend(EnterpriseSimpleInfo vend) {
		this.vend = vend;
	}

	public Date getDate() {
		return date;
	}

	public void setDate(Date date) {
		this.date = date;
	}

	public EnterpriseSimpleInfo getEnterprise() {
		return enterprise;
	}

	public void setEnterprise(EnterpriseSimpleInfo enterprise) {
		this.enterprise = enterprise;
	}

	public Set<PurchaseReturnItemSimpleInfo> getReturnItems() {
		return returnItems;
	}

	public void setReturnItems(Set<PurchaseReturnItemSimpleInfo> returnItems) {
		this.returnItems = returnItems;
	}

	/**
	 * 获取所有可以搜索的字段列名（索引的field名）
	 * 
	 * @return 可以搜索的字段列名
	 */
	public static List<String> getKeywordFields() {
		List<String> fields = new ArrayList<>();
		fields.add(CODE_FIELD);
		fields.add(ITEMS_FIELD);
		fields.add(SENDCODE_FIELD);
		fields.add(ENTERPRISE_FIELD);
		return fields;
	}

	@Override
	public String toString() {
		return "PurchaseReturnSimpleInfo [id=" + id + ", code=" + code + ", sendCode=" + sendCode + ", date=" + date
				+ ", enterprise=" + enterprise + ", vend=" + vend + ", returnItems=" + returnItems + "]";
	}

}
