package com.uas.search.console.b2b.model;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Table;

/**
 * 平台里面，供应商发起的发货单（明细表角度）<br>
 * （以供应商的视角）
 * 
 * @author yingp
 * 
 */
@Table(name = SaleSendSimpleInfo.TABLE_NAME)
@Entity
public class SaleSendSimpleInfo {

	/**
	 * 表名
	 */
	public static final String TABLE_NAME = "SALE$SEND";

	/**
	 * 各字段列名（也是存储索引时的field名）
	 */
	public static final String ID_FIELD = "ss_id";

	public static final String CODE_FIELD = "ss_code";

	public static final String ENTERPRISE_FIELD = "ss_enuu";

	public static final String DATE_FIELD = "ss_date";

	public static final String STATUS_FIELD = "ss_verifystatus";

	public static final String VEND_FIELD = "ss_custuu";

	public static final String ITEMS_FIELD = "si_ssid";

	@Id
	@Column(name = ID_FIELD)
	private Long id;

	/**
	 * 单号
	 */
	@Column(name = CODE_FIELD)
	private String code;

	/**
	 * 日期
	 */
	@Column(name = DATE_FIELD)
	private Date date;

	/**
	 * 企业UU
	 */
	@OneToOne
	@JoinColumn(name = ENTERPRISE_FIELD, insertable = false, updatable = false)
	private EnterpriseSimpleInfo enterprise;

	/**
	 * 客户企业
	 */
	@OneToOne
	@JoinColumn(name = VEND_FIELD, insertable = false, updatable = false)
	private EnterpriseSimpleInfo vend;

	/**
	 * 发货明细
	 */
	@OneToMany(cascade = { CascadeType.ALL }, fetch = FetchType.EAGER)
	@JoinColumn(name = ITEMS_FIELD, insertable = false, updatable = false)
	private Set<SaleSendItemSimpleInfo> sendItems;

	/**
	 * 收料状态 0 未收料，1 未收料
	 */
	@Column(name = STATUS_FIELD)
	private Short verifystatus;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public EnterpriseSimpleInfo getVend() {
		return vend;
	}

	public void setVend(EnterpriseSimpleInfo vend) {
		this.vend = vend;
	}

	public Date getDate() {
		return date;
	}

	public void setDate(Date date) {
		this.date = date;
	}

	public EnterpriseSimpleInfo getEnterprise() {
		return enterprise;
	}

	public void setEnterprise(EnterpriseSimpleInfo enterprise) {
		this.enterprise = enterprise;
	}

	public Set<SaleSendItemSimpleInfo> getSendItems() {
		return sendItems;
	}

	public void setSendItems(Set<SaleSendItemSimpleInfo> sendItems) {
		this.sendItems = sendItems;
	}

	public Short getVerifystatus() {
		return verifystatus;
	}

	public void setVerifystatus(Short verifystatus) {
		this.verifystatus = verifystatus;
	}

	/**
	 * 获取所有可以搜索的字段列名（索引的field名）
	 * 
	 * @return 可以搜索的字段列名
	 */
	public static List<String> getKeywordFields() {
		List<String> fields = new ArrayList<>();
		fields.add(CODE_FIELD);
		fields.add(VEND_FIELD);
		fields.add(ITEMS_FIELD);
		return fields;
	}

	@Override
	public String toString() {
		return "SaleSendSimpleInfo [id=" + id + ", code=" + code + ", date=" + date + ", enterprise=" + enterprise
				+ ", vend=" + vend + ", sendItems=" + sendItems + ", verifystatus=" + verifystatus + "]";
	}

}